@@ -330,6 +330,8 @@ struct vc4_hvs {
 
 	struct clk *core_clk;
 
+	unsigned long max_core_rate;
+
 	/* Memory manager for CRTCs to allocate space in the display
 	 * list.  Units are dwords.
 	 */
@@ -348,7 +350,7 @@ struct vc4_hvs {
 	 * config.txt file to be able to do so and thus won't always be
 	 * available.
 	 */
-	bool vc5_hdmi_enable_scrambling;
+	bool vc5_hdmi_enable_hdmi_20;
 
 	/*
 	 * 4096x2160@60 requires a core overclock to work, so register
